@@ -102,7 +102,7 @@ def first_truthy(*args):
             * If two or more positional arguments are provided, then the value list is the positional argument list.
 
     Returns:
-        Any: the first *truthy* value, if no *truthy* values found or sequence is empty, return ``None``
+        Any: the first *truthy* value, if no *truthy* values found or sequence is empty, return :data:`None`
 
     Raises:
         TypeError: if no arguments provided
@@ -116,7 +116,7 @@ def first_truthy(*args):
 
 
 def first_non_none(*args):
-    """Return the first non-``None`` value from a list of values.
+    """Return the first non-:data:`None` value from a list of values.
 
     Args:
         *args: variable length argument list
@@ -125,7 +125,7 @@ def first_non_none(*args):
             * If two or more positional arguments are provided, then the value list is the positional argument list.
 
     Returns:
-        Any: the first non-``None`` value, if all values are ``None`` or sequence is empty, return ``None``
+        Any: the first non-:data:`None` value, if all values are :data:`None` or sequence is empty, return :data:`None`
 
     Raises:
         TypeError: if no arguments provided
@@ -157,8 +157,8 @@ _boolean_state_lookup = {
 def parse_boolean_state(s):
     """Parse a boolean state from a string representation.
 
-    * These values are regarded as ``True``: ``'1'``, ``'yes'``, ``'y'``, ``'true'``, ``'on'``
-    * These values are regarded as ``False``: ``'0'``, ``'no'``, ``'n'``, ``'false'``, ``'off'``
+    * These values are regarded as :data:`True`: ``'1'``, ``'yes'``, ``'y'``, ``'true'``, ``'on'``
+    * These values are regarded as :data:`False`: ``'0'``, ``'no'``, ``'n'``, ``'false'``, ``'off'``
 
     Value matching is case **insensitive**.
 
@@ -166,7 +166,7 @@ def parse_boolean_state(s):
         s (Optional[str]): string representation of a boolean state
 
     Returns:
-        Optional[bool]: the parsed boolean result, return ``None`` if input is ``None``
+        Optional[bool]: the parsed boolean result, return :data:`None` if input is :data:`None`
 
     Raises:
         ValueError: if ``s`` is an invalid boolean state value
@@ -209,7 +209,7 @@ def parse_linesep(s):
 
     Returns:
         Optional[Literal['\\n', '\\r\\n', '\\r']]: the parsed linesep result,
-        return ``None`` if input is ``None`` or empty string
+        return :data:`None` if input is :data:`None` or empty string
 
     Raises:
         ValueError: if ``s`` is an invalid linesep value
@@ -238,7 +238,7 @@ def parse_indentation(s):
         s (Optional[str]): string representation of indentation
 
     Returns:
-        Optional[str]: the parsed indentation result, return ``None`` if input is ``None`` or empty string
+        Optional[str]: the parsed indentation result, return :data:`None` if input is :data:`None` or empty string
 
     Raises:
         ValueError: if ``s`` is an invalid indentation value
@@ -414,7 +414,7 @@ def recover_files(archive_file):
 
 
 def detect_encoding(code):
-    """Detect encoding of Python source code as specified in `PEP 263`_.
+    """Detect encoding of Python source code as specified in :pep:`263`.
 
     Args:
         code (bytes): the code to detect encoding
@@ -423,10 +423,7 @@ def detect_encoding(code):
         str: the detected encoding, or the default encoding (``utf-8``)
 
     Raises:
-        TypeError: if ``code`` is not a ``bytes`` string
-
-    .. _PEP 263:
-        https://www.python.org/dev/peps/pep-0263/
+        TypeError: if ``code`` is not a :obj:`bytes` string
 
     """
     if not isinstance(code, bytes):
@@ -436,12 +433,12 @@ def detect_encoding(code):
 
 
 class MakeTextIO:
-    """Context wrapper class to handle ``str`` and *file* objects together.
+    """Context wrapper class to handle :obj:`str` and *file* objects together.
 
     Attributes:
         obj (Union[str, TextIO]): the object to manage in the context
         sio (Optional[StringIO]): the I/O object to manage in the context
-            only if :attr:`self.obj <MakeTextIO.obj>` is ``str``
+            only if :attr:`self.obj <MakeTextIO.obj>` is :obj:`str`
         pos (Optional[int]): the original offset of :attr:`self.obj <MakeTextIO.obj>`,
             only if :attr:`self.obj <MakeTextIO.obj>` is a seekable *file* object
 
@@ -459,8 +456,8 @@ class MakeTextIO:
     def __enter__(self):
         """Enter context.
 
-        * If :attr:`self.obj <MakeTextIO.obj>` is ``str``, a
-          ``StringIO`` will be created and returned.
+        * If :attr:`self.obj <MakeTextIO.obj>` is :obj:`str`, a
+          :class:`~io.StringIO` will be created and returned.
 
         * If :attr:`self.obj <MakeTextIO.obj>` is a seekable *file* object,
           it will be seeked to the beginning and returned.
@@ -471,12 +468,13 @@ class MakeTextIO:
         """
         if isinstance(self.obj, str):
             #: StringIO: the I/O object to manage in the context
-            #:     only if :attr:`self.obj <MakeTextIO.obj>` is ``str``
+            #: only if :attr:`self.obj <MakeTextIO.obj>` is :obj:`str`
             self.sio = io.StringIO(self.obj, newline='')  # turn off newline translation # pylint: disable=W0201
             return self.sio
         if self.obj.seekable():
             #: int: the original offset of :attr:`self.obj <MakeTextIO.obj>`,
-            #:     only if :attr:`self.obj <MakeTextIO.obj>` is a seekable ``TextIO``
+            #: only if :attr:`self.obj <MakeTextIO.obj>` is a seekable
+            #: :class:`TextIO <io.TextIOWrapper>`
             self.pos = self.obj.tell()  # pylint: disable=W0201
             #: Union[str, TextIO]: the object to manage in the context
             self.obj.seek(0)
@@ -485,8 +483,8 @@ class MakeTextIO:
     def __exit__(self, exc_type, exc_value, traceback):
         """Exit context.
 
-        * If :attr:`self.obj <MakeTextIO.obj>` is ``str``, the
-          ``StringIO`` (:attr:`self.sio <MakeTextIO.sio>`) will be closed.
+        * If :attr:`self.obj <MakeTextIO.obj>` is :obj:`str`, the
+          :class:`~io.StringIO` (:attr:`self.sio <MakeTextIO.sio>`) will be closed.
 
         * If :attr:`self.obj <MakeTextIO.obj>` is a seekable *file* object,
           its stream position (:attr:`self.pos <MakeTextIO.pos>`) will be recovered.
@@ -550,10 +548,7 @@ def detect_indentation(code):
         In case of mixed indentation, try voting by the number of occurrences of
         each indentation value (*spaces* and *tabs*).
 
-        When there is a tie between *spaces* and *tabs*, prefer **4 spaces** for `PEP 8`_.
-
-    .. _PEP 8:
-        https://www.python.org/dev/peps/pep-0008/
+        When there is a tie between *spaces* and *tabs*, prefer **4 spaces** for :pep:`8`.
 
     """
     if isinstance(code, parso.tree.NodeOrLeaf):
@@ -630,8 +625,19 @@ def _mp_map_wrapper(args):
     return func(*posargs, **kwargs)
 
 
+def _mp_init_lock(lock):  # pragma: no cover
+    """Initialize lock for :mod:`multiprocessing`.
+
+    Args:
+        lock (multiprocessing.synchronize.Lock): the lock to be shared among tasks
+
+    """
+    global task_lock  # pylint: disable=global-statement
+    task_lock = lock
+
+
 def map_tasks(func, iterable, posargs=None, kwargs=None, *, processes=None, chunksize=None):
-    """Execute tasks in parallel if ``multiprocessing`` is available, otherwise execute them sequentially.
+    """Execute tasks in parallel if :mod:`multiprocessing` is available, otherwise execute them sequentially.
 
     Args:
         func (Callable): the task function to execute
@@ -645,6 +651,8 @@ def map_tasks(func, iterable, posargs=None, kwargs=None, *, processes=None, chun
         List[Any]: the return values of the task function applied on the input items and additional arguments
 
     """
+    global task_lock  # pylint: disable=global-statement
+
     if posargs is None:
         posargs = ()
     if kwargs is None:
@@ -653,12 +661,25 @@ def map_tasks(func, iterable, posargs=None, kwargs=None, *, processes=None, chun
     if not parallel_available or processes == 1:  # sequential execution
         return [func(item, *posargs, **kwargs) for item in iterable]
 
-    with mp.Pool(processes=processes or CPU_CNT) as pool:  # parallel execution
-        return pool.map(_mp_map_wrapper, [(func, (item,) + tuple(posargs), kwargs) for item in iterable], chunksize)
+    processes = processes or CPU_CNT
+    lock = mp.Lock()
+    with mp.Pool(processes=processes, initializer=_mp_init_lock, initargs=(lock,)) as pool:  # parallel execution
+        result = pool.map(_mp_map_wrapper, [(func, (item,) + tuple(posargs), kwargs) for item in iterable], chunksize)
+    task_lock = nullcontext()
+    return result
 
 
-#: A lock for possibly concurrent tasks.
-TaskLock = mp.Lock if parallel_available else nullcontext
+task_lock = nullcontext()
+
+
+def TaskLock():
+    """Function that returns a lock for possibly concurrent tasks.
+
+    Returns:
+        Union[contextlib.nullcontext, multiprocessing.synchronize.Lock]: a lock for possibly concurrent tasks
+
+    """
+    return task_lock
 
 
 class Config(collections.abc.MutableMapping):
