@@ -22,7 +22,7 @@ copyright = '2020, Python Backport Compiler Project'  # pylint: disable=redefine
 author = 'Python Backport Compiler Project'
 
 # The full version, including alpha/beta/rc tags
-release = '0.5.4'
+release = '0.5.5'
 
 
 # -- General configuration ---------------------------------------------------
@@ -42,7 +42,8 @@ intersphinx_mapping = {
 }
 
 autodoc_typehints = 'description'
-autodoc_member_order = 'bysource'
+# autodoc_member_order = 'bysource'
+autodoc_member_order = 'groupwise'
 
 # Napoleon settings
 napoleon_google_docstring = True
