@@ -4,11 +4,14 @@ import collections.abc
 import inspect
 import io
 import os
+import re
 import shutil
 import socket
+import subprocess  # nosec
 import sys
 import tarfile
 import tempfile
+import textwrap
 import unittest
 
 import parso
@@ -16,8 +19,8 @@ from bpc_utils import (
     LOOKUP_TABLE, PARSO_GRAMMAR_VERSIONS, BPCSyntaxError, Config, MakeTextIO, TaskLock,
     UUID4Generator, _mp_map_wrapper, archive_files, detect_encoding, detect_files,
     detect_indentation, detect_linesep, expand_glob_iter, first_non_none, first_truthy,
-    get_parso_grammar_versions, is_python_filename, is_windows, map_tasks, parse_boolean_state,
-    parse_indentation, parse_linesep, parso_parse, recover_files)
+    get_parso_grammar_versions, is_python_filename, is_windows, map_tasks, parallel_available,
+    parse_boolean_state, parse_indentation, parse_linesep, parso_parse, recover_files)
 
 
 def read_text_file(filename, encoding='utf-8'):
@@ -462,10 +465,54 @@ class TestBPCUtils(unittest.TestCase):
         self.generic_functional_test()
 
         # test when parallel execution is not available
-        parallel_available = sys.modules['bpc_utils'].parallel_available
+        parallel_available_old = sys.modules['bpc_utils'].parallel_available
         sys.modules['bpc_utils'].parallel_available = False
         self.generic_functional_test()
-        sys.modules['bpc_utils'].parallel_available = parallel_available
+        sys.modules['bpc_utils'].parallel_available = parallel_available_old
+
+    def test_lock(self):
+        num_tasks = 10
+        num_print = 1000
+        code_template = textwrap.dedent("""\
+            from bpc_utils import TaskLock, map_tasks
+
+
+            def task(task_id):
+                {context}
+                    for i in range({num_print}):
+                        print('Task %d says %d' % (task_id, i), flush=True)
+
+
+            if __name__ == '__main__':
+                map_tasks(task, range({num_tasks}))
+        """)
+        code_no_lock = code_template.format(context='for _ in [0]:', num_print=num_print, num_tasks=num_tasks)
+        code_with_lock = code_template.format(context='with TaskLock():', num_print=num_print, num_tasks=num_tasks)
+
+        def has_interleave(output):
+            records = re.findall(r'Task (\d+) says (\d+)', output)
+            task_events = [[] for _ in range(num_tasks)]
+            for i, r in enumerate(records):
+                task_events[int(r[0])].append((i, int(r[1])))
+            for i in range(num_tasks):
+                if [ev[1] for ev in task_events[i]] != list(range(num_print)):  # pragma: no cover
+                    raise ValueError('task %d prints incorrectly' % i)
+            for i in range(num_tasks):
+                start = task_events[i][0][0]
+                if [ev[0] for ev in task_events[i]] != list(range(start, start + num_print)):
+                    return True
+            return False
+
+        shutil.copy(sys.modules['bpc_utils'].__file__, '.')
+        test_filename = 'test-lock.py'
+
+        write_text_file(test_filename, code_no_lock)
+        output = subprocess.check_output([sys.executable, '-u', test_filename]).decode()  # nosec
+        self.assertEqual(has_interleave(output), parallel_available)
+
+        write_text_file(test_filename, code_with_lock)
+        output = subprocess.check_output([sys.executable, '-u', test_filename]).decode()  # nosec
+        self.assertFalse(has_interleave(output))
 
     def test_Config(self):
         config = Config(foo='var', bar=True, boo=1)
